function [Q,W,v2] = Alon(G,n)

% Obtains maximum clique using Alon's algorithm.

N = length(G);



%% Get v2 using Propack.

[V,D] = laneig(G, 2, 'AL');
v2 = V(:,2);


%% Get W, largest entries of second largest eigenvalue.

W = [1:n]; % Initially W is first n entries.

for i = n+1: N
    % Initialize smallest index/value to be i-th.
    sind = i;
    sval = v2(i);
    
    % Check for smallest of W, i.
    for j=1:n
        if v2(W(j)) <= sval
            sval = v2(W(j));
            sind = j;
        end
    end
    
    % Update W if necessary.
    if sind < n % If smallest is in W.
        W(sind) = i;
    end
end

%% Get Q. An index is in Q if it has 3n/4 neighbours in W.
% holds if the sum of G over columns in W is at least 3n/4.

AW = G(:,W); Q = ceil(1/n*(sum(AW,2) - 3*n/4));
            


