function [W, F, X] = Wimage(I, sI, sX, r)

% Converts image information from I to Gaussian kernel (with parameters sI,
% sX, r) as in Shi-Malik.

%% Initialize data.

[m,n] =size(I); % Get dimensions of image.
%nI = norm(I,'fro'); % norm of image matrix.
%I = I/nI; % normalize I.

N = m*n; % total number of pixels.

W = zeros(N); % nodes of similarity graph are pixels.
F = zeros(N,1); % Feature vector (i-th entry is intensity of i-th pixel).
X = zeros(N,2); % Positions of pixels.

%% Extract F and X from I.

pos = 0; % initialize current pixel.

for i=1:m    
    for j=1:n     
        pos = pos + 1;
        F(pos) = I(i,j);
        X(pos, :) = [i,j];
    end
end


%% Write W.

for i=1:N        
    
    for j= (i+1):N        
        d = norm(X(i,:) - X(j,:)); % Get distance between X(i), X(j).        
        % If i and j not too far apart, write W.
        if d < r
            W(i,j) = exp(-(F(i) - F(j))^2/sI^2)*exp(-d^2/sX^2);
            W(j,i) = W(i,j);
        end
    end
end
        
        