function [X, preptime, solvetime, At, b, val] =  kdc_sdpnal_2(G, A1,b1, C)

% Formulates and solves k-disjoint-clique in SDPNAL for given graph G and
% desired number of cliques k.

%% Initialize data.

tic
% Get number of nodes.
n = length(G);

% Have m1=n row sum constraints.
m1 = n;
% Have m2=1 trace constraints.
m2 = 1;
% Number of nonedges m3 is equal to number of zero entries in off-diagonal
% positions of G.
m3 = 0.5*(n*(n-1) - sum(sum(G)) + trace(G));
% Set number of constraints (n + 1 + #nonedges).
m = m1 + m2 + m3;


%% Block for  slack variables.

blk{2, 1} = 'l'; % block is nonnegative vector.
blk{2, 2} = m1; % have one entry for each row sum constraint.

% Set At{2}: top left block is m1 by m1 identity, bottom right block is m3
% by m3 - identity.
At{2,1} = [speye(m1,m1); zeros(m2 + m3, m1)]';

% Allocate temp var for constraints.
Atemp = cell(1,m3);

%% Block for semidefinite variable.
% Semidefinite block  d
blk{1,1} = 's';
blk{1,2} = n;
   

% Right-hand side of constraints.
b2 = zeros(m3, 1);




%% Define entries of At{1} corresponding to nonnedge constraints.

count = 1;
 
 % For each off-diagonal entry check if (i,j) in E.
 for i=1:n
     for j = (i+1):n
         if G(i,j) == 0
             Atemp{count} = spconvert([i,j,0.5; j,i,0.5; n,n, 0]);             
             count = count + 1;
         end
     end
 end
 
%% Convert Atemp to At.

% SDP block.
A2 =svec(blk(1,:), Atemp)';
size(A2{1})
b= [b1;b2];
At{1,1} = [A1,  A2{1}];
%At{1,1} = At{1,1}{1};
preptime = toc;

%% Call SDPNAL to solve.
tic
[val, X] = sdpnal(blk, At, C, b);
X = X{1};
solvetime=toc;
% X = 0;