function [X, preptime, solvetime,  val] = wkdc_sdpnal_2(W,At, b)

% Formulates weighted k-disjoint-clique in format for SDPNAL for given 
% weight matrix W and desired number of cliques k. 
% Solves and exports inputs At, b, blk.

%% Initialize data.

% Start timer.
tic 

% Get number of nodes.
n = length(W);

% Have m1=n row sum constraints.
m1 = n;
% Have m2=1 trace constraints.
m2 = 1;
% Have one nonnegativity constraint for each entry.
m3 = n*(n + 1)/2;
% Set number of constraints (n + 1 + #nonedges).
m = m1 + m2 + m3;

% Semidefinite block 
blk{1,1} = 's';
blk{1,2} = n;

% Slack vars block.
blk{2, 1} = 'l'; % block is nonnegative vector.
blk{2, 2} = m1 + m3; % have one entry for each row sum and nonnegativity constraint.

% Coefficient matrix for SDP var is -W
C{1,1} = -W;
% Coefficient matrix for slack vars is 0.
C{2,1} = spalloc(m-1,1,0);


% Right-hand side of constraints.
%b = [ones(m1,1); k; zeros(m3, 1)]; % Sparsify!

% Stop timer.
preptime = toc; 



%% Call solver.
tic
[val, X] = sdpnal(blk, At, C, b);
X = X{1};
solvetime=toc;


